#
# Conditional build:
%bcond_with	ffmpeg		# FFmpeg instead of GStreamer as generic media extractor
%bcond_with	icu		# ICU instead of enca for MP3 encoding detection
%bcond_with	landlock	# landlock sandboxing (requires kernel 5.13 and landlock enabled in LSM)

%define		abiver	3.0
Summary:	Tracker miners and metadata extractors
Summary(pl.UTF-8):	Narzędzia wydobywania danych dla programu Tracker
Name:		localsearch
Version:	3.9.0
Release:	1
# see COPYING for details
License:	LGPL v2.1+ (libs), GPL v2+ (miners)
Group:		Applications
Source0:	https://download.gnome.org/sources/localsearch/3.9/%{name}-%{version}.tar.xz
# Source0-md5:	6d29c941a4e10eb7fcc6e84d0d90053a
URL:		https://gnome.pages.gitlab.gnome.org/localsearch/
BuildRequires:	NetworkManager-devel
BuildRequires:	asciidoc
# sha256sum
BuildRequires:	coreutils >= 6.0
BuildRequires:	dbus-devel >= 1.3.1
%{!?with_icu:BuildRequires:	enca-devel >= 1.9}
BuildRequires:	exempi-devel >= 2.1.0
# libavcodec libavformat libavutil
%{?with_ffmpeg:BuildRequires:	ffmpeg-devel >= 0.8.4}
BuildRequires:	gexiv2-devel
BuildRequires:	giflib-devel
BuildRequires:	glib2-devel >= 1:2.70.0
BuildRequires:	gstreamer-devel >= 1.20
BuildRequires:	gstreamer-plugins-base-devel >= 1.20
%if %{with ffmpeg}
BuildRequires:	gupnp-dlna-devel >= 0.9.4
%endif
BuildRequires:	libblkid-devel
BuildRequires:	libcue-devel >= 2.0.0
BuildRequires:	libexif-devel >= 0.6
BuildRequires:	libgsf-devel >= 1.14.24
BuildRequires:	libgxps-devel
%{?with_icu:BuildRequires:	libicu-devel >= 4.8.1.1}
BuildRequires:	libiptcdata-devel
BuildRequires:	libjpeg-devel
BuildRequires:	libosinfo-devel >= 0.2.9
BuildRequires:	libpng-devel >= 0.89
%ifnarch alpha ia64 m68k parisc parisc64 riscv64 sh4 sparc sparcv9 sparc64
BuildRequires:	libseccomp-devel >= 2.0
%endif
BuildRequires:	libtiff-devel >= 4
BuildRequires:	libxml2-devel >= 1:2.6
BuildRequires:	libxslt-progs
%{?with_landlock:BuildRequires:	linux-libc-headers >= 7:5.13}
BuildRequires:	meson >= 0.51
BuildRequires:	ninja >= 1.5
BuildRequires:	pkgconfig
BuildRequires:	poppler-glib-devel >= 0.16.0
BuildRequires:	rpmbuild(macros) >= 2.042
BuildRequires:	tar >= 1:1.22
BuildRequires:	tinysparql-devel >= 3.8
BuildRequires:	totem-pl-parser-devel
BuildRequires:	upower-devel >= 0.9.0
BuildRequires:	xz
BuildRequires:	zlib-devel
Requires(post,preun):	systemd-units >= 1:250.1
Requires:	dbus >= 1.3.1
%{!?with_icu:Requires:	enca-libs >= 1.9}
Requires:	exempi >= 2.1.0
Requires:	glib2 >= 1:2.70.0
Requires:	gstreamer >= 1.20
Requires:	gstreamer-plugins-base >= 1.20
%if %{with ffmpeg}
Requires:	gupnp-dlna >= 0.9.4
%endif
Requires:	libcue >= 2.0.0
Requires:	libexif >= 0.6
Requires:	libgsf >= 1.14.24
Requires:	libosinfo >= 0.2.9
Requires:	libxml2 >= 1:2.6
Requires:	systemd-units >= 1:250.1
Requires:	tinysparql >= 3.8
%{?with_landlock:Requires:	uname(release) >= 5.13}
Obsoletes:	tracker3-miners < 3.8.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
This package contains various miners and metadata extractors for
tracker.

%description -l pl.UTF-8
Ten pakiet zawiera narzędzia wydobywania danych dla programu Tracker.

%package testutils
Summary:	Tracker 3 test utilities
Summary(pl.UTF-8):	Narzędzia testowe Trackera 3
Group:		Development/Tools
Requires:	dbus
Requires:	%{name} = %{version}-%{release}
Requires:	python3 >= 1:3.2
Requires:	python3-pygobject3 >= 3
Obsoletes:	tracker3-testutils < 3.8.0

%description testutils
Tracker 3 test utilities.

%description testutils -l pl.UTF-8
Narzędzia testowe Trackera 3.

%prep
%setup -q

%build
%meson \
	--default-library=shared \
	-Dbattery_detection=upower \
	-Dcharset_detection=%{?with_icu:icu}%{!?with_icu:enca} \
	-Dcue=enabled \
	-Dexif=enabled \
	-Dfanotify=enabled \
	-Dfunctional_tests=false \
	-Dgif=enabled \
	-Dgsf=enabled \
	-Diptc=enabled \
	-Diso=enabled \
	-Djpeg=enabled \
	-Dlandlock=%{__enabled_disabled landlock} \
	-Dlibav=%{__enabled_disabled ffmpeg} \
	-Dpdf=enabled \
	-Dplaylist=enabled \
	-Dpng=enabled \
	-Draw=enabled \
	-Dsystemd_user_services_dir=%{systemduserunitdir} \
	-Dtiff=enabled \
	-Dxml=enabled \
	-Dxmp=enabled \
	-Dxps=enabled

%meson_build

%install
rm -rf $RPM_BUILD_ROOT

%meson_install

%find_lang localsearch3

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with landlock}
%verifyscript
if ! grep -q -s '\<landlock\>' /sys/kernel/security/lsm ; then
	echo "LANDLOCK LSM not enabled in kernel"
fi
%endif

%post
%glib_compile_schemas
%systemd_user_post localsearch-3.service localsearch-control-3.service localsearch-writeback-3.service

%preun
%systemd_user_preun localsearch-3.service localsearch-control-3.service localsearch-writeback-3.service

%postun
%glib_compile_schemas

%files -f localsearch3.lang
%defattr(644,root,root,755)
%doc AUTHORS COPYING MAINTAINERS NEWS README.md
%attr(755,root,root) %{_bindir}/localsearch
%attr(755,root,root) %{_libexecdir}/localsearch-3
%attr(755,root,root) %{_libexecdir}/localsearch-control-3
%attr(755,root,root) %{_libexecdir}/localsearch-extractor-3
%attr(755,root,root) %{_libexecdir}/localsearch-writeback-3
%{systemduserunitdir}/localsearch-3.service
%{systemduserunitdir}/localsearch-control-3.service
%{systemduserunitdir}/localsearch-writeback-3.service
/etc/xdg/autostart/localsearch-3.desktop
%dir %{_libdir}/localsearch-%{abiver}
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/libtracker-extract.so
%dir %{_libdir}/localsearch-%{abiver}/extract-modules
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-abw.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-bmp.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-desktop.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-disc-generic.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-dummy.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-epub.so
# R: giflib
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-gif.so
# R: libxml2
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-html.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-icon.so
# R: libosinfo
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-iso.so
# R: libiptcdata libjpeg
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-jpeg.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-mp3.so
# R: libgsf
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-msoffice.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-msoffice-xml.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-oasis.so
# R: poppler-glib
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-pdf.so
# R: totem-plparser
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-playlist.so
# R: libpng
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-png.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-ps.so
# R: libgexiv2
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-raw.so
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-text.so
# R: libtiff
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-tiff.so
# R: libgxps
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/extract-modules/libextract-xps.so
%dir %{_libdir}/localsearch-%{abiver}/writeback-modules
# R: gstreamer gstreamer-plugins-base
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/writeback-modules/libwriteback-gstreamer.so
# R: exempi
%attr(755,root,root) %{_libdir}/localsearch-%{abiver}/writeback-modules/libwriteback-xmp.so
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.xml
%{_datadir}/dbus-1/interfaces/org.freedesktop.Tracker3.Miner.Files.Index.xml
%{_datadir}/dbus-1/services/org.freedesktop.LocalSearch3.service
%{_datadir}/dbus-1/services/org.freedesktop.LocalSearch3.Control.service
%{_datadir}/dbus-1/services/org.freedesktop.LocalSearch3.Writeback.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Miner.Files.Control.service
%{_datadir}/dbus-1/services/org.freedesktop.Tracker3.Writeback.service
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.Extract.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.FTS.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.Tracker3.Miner.Files.gschema.xml
%{_datadir}/glib-2.0/schemas/org.freedesktop.TrackerMiners3.enums.xml
%dir %{_datadir}/localsearch3
%dir %{_datadir}/localsearch3/domain-ontologies
%{_datadir}/localsearch3/domain-ontologies/default.rule
%dir %{_datadir}/localsearch3/extract-rules
# standalone (builtin?) rules
%{_datadir}/localsearch3/extract-rules/10-comics.rule
%{_datadir}/localsearch3/extract-rules/10-ebooks.rule
%{_datadir}/localsearch3/extract-rules/10-folder.rule
%{_datadir}/localsearch3/extract-rules/10-svg.rule
%{_datadir}/localsearch3/extract-rules/15-executable.rule
%{_datadir}/localsearch3/extract-rules/15-games.rule
# modules
%{_datadir}/localsearch3/extract-rules/10-abw.rule
%{_datadir}/localsearch3/extract-rules/10-bmp.rule
%{_datadir}/localsearch3/extract-rules/10-desktop.rule
%{_datadir}/localsearch3/extract-rules/10-epub.rule
%{_datadir}/localsearch3/extract-rules/10-gif.rule
%{_datadir}/localsearch3/extract-rules/10-html.rule
%{_datadir}/localsearch3/extract-rules/10-ico.rule
%{_datadir}/localsearch3/extract-rules/10-jpeg.rule
%{_datadir}/localsearch3/extract-rules/10-mp3.rule
%{_datadir}/localsearch3/extract-rules/10-msoffice.rule
%{_datadir}/localsearch3/extract-rules/10-oasis.rule
%{_datadir}/localsearch3/extract-rules/10-pdf.rule
%{_datadir}/localsearch3/extract-rules/10-png.rule
%{_datadir}/localsearch3/extract-rules/10-ps.rule
%{_datadir}/localsearch3/extract-rules/10-raw.rule
%{_datadir}/localsearch3/extract-rules/10-tiff.rule
%{_datadir}/localsearch3/extract-rules/10-xps.rule
%{_datadir}/localsearch3/extract-rules/11-iso.rule
%{_datadir}/localsearch3/extract-rules/11-msoffice-xml.rule
%{_datadir}/localsearch3/extract-rules/15-playlist.rule
# libextract-text
%{_datadir}/localsearch3/extract-rules/15-text.rule
%{_datadir}/localsearch3/extract-rules/90-disc-generic.rule
%dir %{_datadir}/localsearch3/miners
%{_datadir}/localsearch3/miners/org.freedesktop.Tracker3.Miner.Files.service
%{_mandir}/man1/localsearch-3.1*
%{_mandir}/man1/localsearch-daemon.1*
%{_mandir}/man1/localsearch-extract.1*
%{_mandir}/man1/localsearch-index.1*
%{_mandir}/man1/localsearch-info.1*
%{_mandir}/man1/localsearch-reset.1*
%{_mandir}/man1/localsearch-search.1*
%{_mandir}/man1/localsearch-status.1*
%{_mandir}/man1/localsearch-tag.1*
%{_mandir}/man1/localsearch-writeback-3.1*

%files testutils
%defattr(644,root,root,755)
%dir %{_libdir}/localsearch-3.0/trackertestutils
%attr(755,root,root) %{_libdir}/localsearch-3.0/trackertestutils/localsearch3-test-sandbox
%{_libdir}/localsearch-3.0/trackertestutils/*.py
%changelog
* Thu Apr 24 2025 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/localsearch.git;a=log;h=master

* Wed Apr 23 2025 Jakub Bogusz <qboosh@pld-linux.org> 4a0d8c0
- updated to 3.9.0 (GNOME 48)

* Fri Dec 20 2024 Jan Rękorajski <baggins@pld-linux.org> 0b743df
- add Obsoletes for tracker3-miners, rel 2

* Wed Dec 11 2024 Jakub Bogusz <qboosh@pld-linux.org> e27b326
- updated to 3.8.2

* Sun Nov 24 2024 Jakub Bogusz <qboosh@pld-linux.org> 9466888
- updated to 3.8.1

* Mon Sep 16 2024 Jakub Bogusz <qboosh@pld-linux.org> 920eb71
- tracker3-miners continued as localsearch, updated to 3.8.0 (GNOME 47)

* Mon May 06 2024 Jakub Bogusz <qboosh@pld-linux.org> 88bd806
- updated to 3.7.3

* Sat Apr 27 2024 Jakub Bogusz <qboosh@pld-linux.org> 0de6aee
- updated to 3.7.2

* Wed Mar 27 2024 Jakub Bogusz <qboosh@pld-linux.org> 571123c
- updated to 3.7.1

* Sun Mar 24 2024 Jakub Bogusz <qboosh@pld-linux.org> 89b2f29
- updated to 3.7.0

* Tue Oct 31 2023 Jakub Bogusz <qboosh@pld-linux.org> 24d7ae1
- updated to 3.6.2

* Mon Oct 02 2023 Jakub Bogusz <qboosh@pld-linux.org> a22094f
- updated to 3.6.1

* Sat Sep 23 2023 Jakub Bogusz <qboosh@pld-linux.org> e18590a
- updated to 3.6.0

* Sun Jul 23 2023 Jakub Bogusz <qboosh@pld-linux.org> 8204b83
- updated to 3.5.2 (GNOME 44)

* Thu Mar 23 2023 Jakub Bogusz <qboosh@pld-linux.org> ea07efd
- updated to 3.4.3

* Wed Dec 07 2022 Jakub Bogusz <qboosh@pld-linux.org> 493d357
- updated to 3.4.2

* Thu Oct 27 2022 Jakub Bogusz <qboosh@pld-linux.org> ea61ca6
- updated to 3.4.1

* Fri Sep 30 2022 Jakub Bogusz <qboosh@pld-linux.org> 7210870
- updated to 3.4.0

* Mon Jun 06 2022 Jakub Bogusz <qboosh@pld-linux.org> ef3a694
- updated to 3.3.1

* Mon Apr 04 2022 Jakub Bogusz <qboosh@pld-linux.org> 9e573bd
- updated to 3.3.0

* Mon Jan 10 2022 Jan Rękorajski <baggins@pld-linux.org> c23c07a
- systemd user service startup, rel 2

